#
# spec file for package nginx-0.8
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           nginx-0.8
Version:        0.8.53
Release:        4.14.1
#
%define pkg_name nginx
#
%define ngx_prefix     %{_prefix}
%define ngx_sbindir    %{_sbindir}/nginx
%define ngx_conf_dir   %{_sysconfdir}/nginx
%define ngx_conf_path  %{ngx_conf_dir}/nginx.conf
%define ngx_error_log  /var/log/nginx/error.log
%define ngx_access_log /var/log/nginx/access.log
%define ngx_pid_path   /var/run/nginx.pid
%define ngx_lock_path  /var/run/nginx.lock
%define ngx_home       /var/lib/nginx
%define ngx_tmp_http   %{ngx_home}/tmp/
%define ngx_tmp_proxy  %{ngx_home}/proxy/
%define ngx_tmp_fcgi   %{ngx_home}/fastcgi/
%define ngx_user_group nginx
%define rubygem_passenger_version 3.0.2
#
License:        BSD
#
Summary:        A HTTP server and IMAP/POP3 proxy server
#
Url:            http://nginx.net/
Group:          Productivity/Networking/Web/Proxy
Source:         http://sysoev.ru/nginx/nginx-%{version}.tar.bz2
Source1:        nginx.init
# PATCH-FIX-UPSTREAM nginx-0.4.0-no_Werror.patch
Patch:          nginx-0.4.0-no_Werror.patch
# PATCH-FIX-UPSTREAM nginx-0.6.31-DESTDIR.patch
# Patch1:         nginx-0.6.31-DESTDIR.patch
# Patch2:         nginx-0.4.0-html.patch
# PATCH-FIX-UPSTREAM nginx-0.6.38-html.patch
Patch2:         nginx-0.6.38-html.patch
# PATCH-FIX-UPSTREAM nginx-0.4.0-perl_vendor_install.patch
Patch3:         nginx-0.4.0-perl_vendor_install.patch
# PATCH-FIX-UPSTREAM nginx-0.6.31_default_config.patch
Patch4:         nginx-0.6.31_default_config.patch
# PATCH-FIX-UPSTREAM
Patch5:         nginx_heap_overflow_4315.patch
# PATCH CVE-2012-1180
Patch6:         nginx-CVE-2012-1180.patch

BuildRequires:  dos2unix
BuildRequires:  gd-devel
BuildRequires:  libxslt-devel
BuildRequires:  openssl-devel
BuildRequires:  pcre-devel
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
BuildRequires:  rubygem-passenger-nginx = %rubygem_passenger_version
BuildRequires:  gcc-c++
BuildRequires:  libcurl-devel
Requires:       rubygem-passenger-nginx, pcre
PreReq:         %fillup_prereq
PreReq:         %insserv_prereq
PreReq:         pwdutils
Provides:       nginx = %{version}
Provides:       nginx-passenger = %{version}
#
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Conflicts:      nginx-0.5 nginx-0.6 nginx-0.7
%requires_eq    perl

%description
nginx [engine x] is a HTTP server and IMAP/POP3 proxy server written by Igor Sysoev.
It has been running on many heavily loaded Russian sites for more than two years.

Author:
-------
    Igor Sysoev

%prep
%setup -n %{pkg_name}-%{version}
%patch
#%patch1
%patch2
%patch3
%patch4
%patch5
%patch6
dos2unix contrib/geo2nginx.pl

%build
#copy source from rubygem-passenger in order to
#generate *.o files which will be needed for nxing comilation
cp -R %{_libdir}/ruby/gems/%{rb_ver}/gems/passenger-%{rubygem_passenger_version} .
pushd passenger-%{rubygem_passenger_version}/
  rm ext/libev/*.lo
  export PATH="%{_sbindir}:$PATH"

  #compiling nginx stuff for passenger
  rake nginx:clean nginx CACHING=no
popd

 ./configure \
   --prefix=%{ngx_prefix}/ \
   --sbin-path=%{ngx_sbindir} \
   --conf-path=%{ngx_conf_path} \
   --error-log-path=%{ngx_error_log} \
   --http-log-path=%{ngx_access_log} \
   --pid-path=%{ngx_pid_path} \
   --lock-path=%{ngx_lock_path} \
   --http-client-body-temp-path=%{ngx_tmp_http} \
   --http-proxy-temp-path=%{ngx_tmp_proxy} \
   --http-fastcgi-temp-path=%{ngx_tmp_fcgi} \
   --user=nginx --group=nginx \
   --with-rtsig_module \
   --with-select_module \
   --with-poll_module \
   --with-ipv6 \
 %if 0%{?sles_version} == 11 || 0%{?suse_version} == 1030 || 0%{?suse_version} == 1100 || 0%{?suse_version} == 1110 || 0%{?suse_version} > 1110  
   --with-file-aio \
 %endif  
   --with-http_ssl_module             \
   --with-http_realip_module          \
   --with-http_addition_module        \
   --with-http_xslt_module            \
   --with-http_image_filter_module    \
   --with-http_sub_module             \
   --with-http_dav_module             \
   --with-http_flv_module             \
   --with-http_gzip_static_module     \
   --with-http_random_index_module    \
   --with-http_secure_link_module     \
   --with-http_stub_status_module     \
   --with-http_perl_module            \
   --with-perl=%{_bindir}/perl \
   --with-mail \
   --with-md5=/usr \
   --with-sha1=/usr \
   --with-pcre \
   --add-module=passenger-%{rubygem_passenger_version}/ext/nginx \
 %if 0%{?suse_version} > 1000 || 0%{?fedora_version} > 4 || 0%{?mandriva_version} > 2006  
   --with-cc-opt="%{optflags} -fstack-protector"
 %else  
   --with-cc-opt="%{optflags}"
 %endif  
%{__make}

%install
%makeinstall
%perl_process_packlist
#
%{__install} -d -m 0750 %{buildroot}%{ngx_home}/{,tmp,proxy,fastcgi}
#
%{__install} -D -m 0755 %{S:1} %{buildroot}%{_sysconfdir}/init.d/%{pkg_name}
%{__ln_s} -f %{_sysconfdir}/init.d/%{pkg_name} %{buildroot}%{_sbindir}/rc%{pkg_name}
%{__rm} -rf passenger-%{rubygem_passenger_version}/
%{__rm} %{buildroot}/srv/www/htdocs/index.html

%post
%fillup_and_insserv %{pkg_name}

%preun
%stop_on_removal %{pkg_name}

%postun
%restart_on_update %{pkg_name}
%{insserv_cleanup}

%clean
%{__rm} -rf %{buildroot}

%pre
/usr/sbin/groupadd -r %{ngx_user_group} &>/dev/null ||:
/usr/sbin/useradd -g %{ngx_user_group} -s /bin/false -r -c "user for %{ngx_user_group}" -d %{ngx_home} %{ngx_user_group} &>/dev/null ||:

%files
%defattr(-,root,root,-)
%dir %{ngx_conf_dir}/
%config(noreplace) %{ngx_conf_dir}/koi-utf
%config(noreplace) %{ngx_conf_dir}/koi-win
%config(noreplace) %{ngx_conf_dir}/fastcgi_params
%config(noreplace) %{ngx_conf_dir}/fastcgi_params.default
%config(noreplace) %{ngx_conf_dir}/mime.types
%config(noreplace) %{ngx_conf_dir}/mime.types.default
%config(noreplace) %{ngx_conf_dir}/nginx.conf
%config(noreplace) %{ngx_conf_dir}/nginx.conf.default
%config(noreplace) %{ngx_conf_dir}/fastcgi.conf
%config(noreplace) %{ngx_conf_dir}/fastcgi.conf.default
%config(noreplace) %{ngx_conf_dir}/win-utf
%config(noreplace) %{ngx_conf_dir}/scgi_params
%config(noreplace) %{ngx_conf_dir}/scgi_params.default
%config(noreplace) %{ngx_conf_dir}/uwsgi_params
%config(noreplace) %{ngx_conf_dir}/uwsgi_params.default
%dir %{perl_vendorarch}/auto/nginx/
%if 0%{?suse_version} == 0 || 0%{?suse_version} <= 1130
%{perl_vendorarch}/auto/nginx/.packlist
%endif
%{perl_vendorarch}/auto/nginx/nginx.bs
%{perl_vendorarch}/auto/nginx/nginx.so
%{perl_vendorarch}/nginx.pm
%{ngx_sbindir}
%{_mandir}/man3/nginx.3pm*
/srv/www/htdocs/50x.html
%if 0%{?suse_version} == 0 || 0%{?suse_version} <= 1130
%{_localstatedir}/adm/perl-modules/%{name}
%endif
%{_sysconfdir}/init.d/%{pkg_name}
%{_sbindir}/rc%{pkg_name}
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) /var/log/nginx/
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) %{ngx_home}/
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) %{ngx_home}/tmp/
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) %{ngx_home}/proxy/
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) %{ngx_home}/fastcgi/
%doc CHANGES* LICENSE README
%doc conf/ contrib/

%changelog
* Mon Mar 19 2012 schubi@suse.com
- Fixed VUL-0: CVE-2012-1180 nginx: information leak
  (bnc #752482)
* Mon Nov 21 2011 schubi@suse.com
- Fixed VUL-0: CVE-2011-4315: nginx: heap overflow (bnc #731084)
  nginx_heap_overflow_4315.patch
* Wed Feb  9 2011 schubi@novell.com
- remove /srv/www/htdocs/index.html (bnc#670031)
* Tue Dec 21 2010 lslezak@suse.cz
- fixed packaging on openSUSE-11.4 - some perl-files are not
  generated
* Thu Nov  4 2010 alexandre@exatati.com.br
- Update to 0.8.53:
  * Feature: now the "error_page" directive allows to change a status
    code in a redirect.
  * Feature: the "gzip_disable" directive supports special "degradation"
    mask.
  * Bugfix: a socket leak might occurred if file AIO was used.
    Thanks to Maxim Dounin.
  * Bugfix: if the first server had no "listen" directive and there was
    no explicit default server, then a next server with a "listen"
    directive became the default server; the bug had appeared in 0.8.21.
* Sat Oct 16 2010 cristian.rodriguez@opensuse.org
- Update to version 0.8.52
  * Bugfix: nginx used SSL mode for a listen socket if any listen option
    was set; the bug had appeared in 0.8.51.
  * Change: the "secure_link_expires" directive has been canceled.
  * Change: a logging level of resolver errors has been lowered from
    "alert" to "error".
  * Feature: now a listen socket "ssl" parameter may be set several
    times.
* Wed Sep  8 2010 alexandre@exatati.com.br
- Update to 0.8.50;
- Bzip2 source file;
- Spec file cleaned with spec-cleaner.
* Wed Jun 23 2010 jg@internetx.de
- update to 0.8.42
* Thu Apr 29 2010 mrueckert@suse.de
- update to 0.8.36
* Mon Feb  8 2010 jg@internetx.de
- 0.8.33
* Tue Dec 15 2009 jg@internetx.de
- bumped to 0.8.29
* Wed Nov 18 2009 jg@internetx.de
  update to 0.8.27
* Tue Nov 17 2009 jg@internetx.de
- 0.8.26
- enabled file-aio for sle11 & opensuse 10.3 -> Factory
* Wed Nov 11 2009 jg@internetx.de
- 0.8.23
* Wed Nov  4 2009 jg@internetx.de
- 0.8.22
* Wed Oct 28 2009 jg@internetx.de
- 0.8.21
* Wed Oct 14 2009 jg@internetx.de 
- 0.8.20
* Mon Sep 28 2009 jg@internetx.de
- 0.8.17
* Fri Sep 25 2009 jg@internetx.de
- 0.8.16
* Mon Sep 14 2009 jg@internetx.de
- 0.8.15
* Wed Sep  9 2009 jg@internetx.de
- 0.8.14
* Mon Aug 31 2009 jg@internetx.de
- 0.8.11
* Thu Aug 20 2009 jg@internetx.de
- 0.8.9
* Mon Aug 10 2009 jg@internetx.de
- 0.8.8
* Mon Jul 20 2009 jg@internetx.de
- upgrade to version 0.8.6
* Mon Jul 13 2009 jg@internetx.de
- upgrade to version 0.8.5
* Tue Jun 23 2009 jg@internetx.de
- start packaging the 0.8 branch
